@@ -17,7 +17,9 @@ except ImportError:
 def _validate_theta(
         thetas: List[Number], theta_start: Number, theta_stop: Number,
         theta_step: Number
-    ) -> "np.array":
+    ) -> np.ndarray:
+    """Return a numpy array of theta values after validating & standartising
+        the input list of theta values"""
     theta_values = (theta_start, theta_stop, theta_step)
     multiple_thetas = thetas is not None and any(theta_values)
     if multiple_thetas:
@@ -40,8 +42,8 @@ def _get_products_of_inputs(*args) -> Tuple[Number]:
     product = list(itertools.product(*list_of_lists))
     return product
 
-def _validate_only_one_iterable(*args) -> bool:
-    """Return validation check that only one argument passed to create_range is an iterable"""
+def _validate_only_one_iterable(*args) -> None:
+    """Validation check that only one argument passed to create_range is an iterable"""
     inputs = collections.Counter([isinstance(el, collections.abc.Iterable) for el in args])
     if inputs[True] > 1:
         raise ValueError((
@@ -94,8 +96,8 @@ def _trace_loop(
         screen_size: Tuple[Number, Number], screen_color: str, color: str,
         width: Number, screen_coords: Tuple[Number, Number], padding: Number,
         frame_pause: Number
-    ) -> None:
-    """Loop over a given array of shapes and draw them"""
+    ) -> Tuple["turtle.Screen", "namedtuple"]:
+    """Returns a turtle screen and namedtuple containing turtles..."""
     for shape in shapes_arr:
         if screen is not None:
             turtles.shape_turtle.clear()
