@@ -90,7 +90,7 @@ class _Trochoid(ABC):
 
         self.coords = list(zip(self.x, self.y, self.thetas))
 
-    def transform(self, x: Number = 0, y: Number = 0) -> "_Trochoid":
+    def translate(self, x: Number = 0, y: Number = 0) -> "_Trochoid":
         """
         Return a new shape translated by the given x and y offsets.
 
@@ -113,7 +113,7 @@ class _Trochoid(ABC):
         """
         # pylint: disable=no-value-for-parameter
         try:
-            transformed_shape = self.__class__(
+            translated_shape = self.__class__(
                 R=self.R,
                 r=self.r,
                 d=self.d,
@@ -121,13 +121,13 @@ class _Trochoid(ABC):
                 origin=(self.origin[0]+x, self.origin[1]+y)
             )
         except TypeError:
-            transformed_shape = self.__class__(
+            translated_shape = self.__class__(
                 R=self.R,
                 r=self.r,
                 thetas=self.thetas,
                 origin=(self.origin[0]+x, self.origin[1]+y)
             )
-        return transformed_shape
+        return translated_shape
 
     def scale(self, factor: Number) -> Union["_Trochoid", "_Cycloid"]:
         """Return shape with input parameters scaled by a given input factor.
@@ -573,7 +573,7 @@ class _Trochoid(ABC):
             ))
         return shapes
 
-    def _show_full_path(self, pre_draw_turtle: "turtle.Turtle") -> None:
+    def _show_full_path(self, pre_draw_turtle: "turtle.Turtle") -> turtle.Turtle:
         """Draw the full path prior to tracing"""
         # pylint: disable=no-member, unused-variable
         first = True
@@ -703,15 +703,15 @@ class _Trochoid(ABC):
     def _draw_circle(
             self, t: "turtle.Turtle", x: float, y: float, radius: float
         ) -> None:
-        """Draw circle"""
+        """Draws a circle with a given center point and radius on the current turtle canvas"""
         t.up()
         t.seth(0)
         t.goto(x, y)
         t.down()
         t.circle(radius, steps=200)
 
-    def _draw_rolling_circle(self, t: "turtle.Turtle", theta: Number) -> None:
-        """Draw the rolling circle on the screen"""
+    def _draw_rolling_circle(self, t: "turtle.Turtle", theta: Number) -> Tuple[Number, Number]:
+        """Returns x and y coordinates for a rolling circle"""
         x=self._circle_offset()*math.cos(theta) + self.origin[0]
         y=self._circle_offset()*math.sin(theta) - self.r + self.origin[1]
         self._draw_circle(
